@@ -269,7 +269,6 @@ OC.L10N.register(
     "Select conversation" : "Selecciona conversación",
     "on" : "activo",
     "at" : "a",
-    "Reminder" : "Recordatorio",
     "before at" : "antes de las",
     "Notification" : "Notificación",
     "Email" : "Correo electrónico",
@@ -280,7 +279,6 @@ OC.L10N.register(
     "Edit time" : "Hora de edición",
     "Save time" : "Guardar hora",
     "Remove reminder" : "Eliminar recordatorio",
-    "+ Add reminder" : "+ Añadir recordatorio",
     "Add reminder" : "Añadir recordatorio",
     "seconds" : "seconds",
     "minutes" : "minutos",
@@ -315,26 +313,25 @@ OC.L10N.register(
     "Awaiting response" : "Esperando respuesta",
     "Checking availability" : "Comprobando disponibilidad",
     "Has not responded to {organizerName}'s invitation yet" : "Todavía no ha respondido a la invitación de {organizerName}.",
-    "Select automatic slot" : "Seleccione un espacio de tiempo automático",
     "chairperson" : "moderador",
     "required participant" : "participante requerido",
     "non-participant" : "no es participante",
     "optional participant" : "participante opcional",
     "{organizer} (organizer)" : "{organizer} (organizador)",
     "{attendee} ({role})" : "{attendee} ({role})",
-    "Free" : "Libre",
-    "Busy (tentative)" : "Ocupado (provisional)",
-    "Busy" : "Ocupado",
-    "Out of office" : "Fuera de la oficina",
-    "Unknown" : "Desconocido",
     "Availability of attendees, resources and rooms" : "Disponibilidad de asistentes, recursos y habitaciones",
-    "with" : "con",
-    "Available times:" : "Horas disponibles:",
     "Suggestion accepted" : "Sugerencia aceptada",
+    "Legend" : "Leyenda",
+    "Out of office" : "Fuera de la oficina",
+    "Attendees:" : "Asistentes:",
     "Done" : "Listo",
     "Search room" : "Buscar sala",
     "Room name" : "Nombre de la sala",
     "Check room availability" : "Comprueba la disponibilidad de la sala",
+    "Free" : "Libre",
+    "Busy (tentative)" : "Ocupado (provisional)",
+    "Busy" : "Ocupado",
+    "Unknown" : "Desconocido",
     "Find a time" : "Buscar una hora",
     "The invitation has been accepted successfully." : "La invitación se ha aceptado con éxito.",
     "Failed to accept the invitation." : "Fallo al aceptar la invitación.",
@@ -372,7 +369,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "No se puede modificar el ajuste de todo el día en eventos que son parte de una serie recurrente.",
     "From" : "De",
     "To" : "A",
-    "All day" : "Todo el día",
     "Repeat" : "Repetir",
     "_time_::_times_" : ["vez","veces","veces"],
     "never" : "nunca",
@@ -395,7 +391,7 @@ OC.L10N.register(
     "Does not repeat" : "No repetir",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Nextcloud no admite totalmente la definición de recurrencia de este evento. Si edita las opciones de recurrencia, ciertas repeticiones pueden perderse.",
     "No rooms or resources yet" : "Aún no hay salas ni recursos",
-    "Suggestions" : "Sugerencias",
+    "Resources" : "Recursos",
     "_{seatingCapacity} seat_::_{seatingCapacity} seats_" : ["{seatingCapacity} asiento","{seatingCapacity} asientos","{seatingCapacity} asientos"],
     "Add resource" : "Añade recurso",
     "Has a projector" : "Tiene un proyector",
@@ -462,15 +458,15 @@ OC.L10N.register(
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "La detección automática de la zona horaria determinó que tu zona horaria sea UTC. Esto es probablemente el resultado de las medidas de seguridad de su navegador web. Por favor establezca su zona horaria manualmente en la configuración del calendario. ",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "No se ha encontrado la zona horaria configurada ({timezoneId}). Volviendo a UTC.\nPor favor, cambia tu zona horaria en la configuración e informa de este problema.",
     "Availability of {displayName}" : "Disponibilidad de {displayName}",
+    "Edit event" : "Editar evento",
     "Event does not exist" : "el evento no existe",
     "Duplicate" : "Duplicar",
     "Delete this occurrence" : "Eliminar esta ocurrencia",
     "Delete this and all future" : "Eliminar este y los futuros",
-    "Details" : "Detalles",
+    "All day" : "Todo el día",
     "Managing shared access" : "Administrando el acceso compartido",
     "Deny access" : "Denegar acceso",
     "Invite" : "Invitar",
-    "Resources" : "Recursos",
     "_User requires access to your file_::_Users require access to your file_" : ["El usuario requieren acceso a su archivo","Los usuarios requieren acceso a su archivo","Los usuarios requieren acceso a su archivo"],
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Adjunto que requiere acceso compartido","Adjuntos que requieren acceso compartido","Adjuntos que requieren acceso compartido"],
     "Untitled event" : "Evento sin título",
@@ -561,6 +557,7 @@ OC.L10N.register(
     "Special color of this event. Overrides the calendar-color." : "Color especial de este evento. Reemplazará al color de calendario.",
     "Error while sharing file" : "Error al compartir archivo",
     "Error while sharing file with user" : "Error al compartir el archivo con el usuario",
+    "Error creating a folder {folder}" : "Error creando la carpeta {folder}",
     "Attachment {fileName} already exists!" : "¡El adjunto {fileName} ya existe!",
     "An error occurred during getting file information" : "Ocurrió un error al obtener la información del archivo",
     "Talk conversation for event" : "Conversación de Talk para el evento",
@@ -569,6 +566,13 @@ OC.L10N.register(
     "This is an event reminder." : "Esto es un recordatorio de evento.",
     "Error while parsing a PROPFIND error" : "Error al analizar un error PROPFIND",
     "Appointment not found" : "Cita no encontrada",
-    "User not found" : "Usuario no encontrado"
+    "User not found" : "Usuario no encontrado",
+    "Reminder" : "Recordatorio",
+    "+ Add reminder" : "+ Añadir recordatorio",
+    "Select automatic slot" : "Seleccione un espacio de tiempo automático",
+    "with" : "con",
+    "Available times:" : "Horas disponibles:",
+    "Suggestions" : "Sugerencias",
+    "Details" : "Detalles"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
