@@ -1,12 +1,12 @@
 OC.L10N.register(
     "calendar",
     {
-    "Provided email-address is too long" : "Alamat surel yang diberikan terlalu panjang",
+    "Provided email-address is too long" : "Alamat email yang diberikan terlalu panjang",
     "User-Session unexpectedly expired" : "Sesi-Pengguna kedaluwarsa secara tidak terduga",
-    "Provided email-address is not valid" : "Alamat surel tidak valid",
+    "Provided email-address is not valid" : "Alamat email tidak valid",
     "%s has published the calendar »%s«" : "%s telah mempublikasikan kalender »%s«",
-    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim surel. Silakan hubungi administrator Anda.",
-    "Successfully sent email to %1$s" : "Berhasil mengirim surel ke %1$s",
+    "Unexpected error sending email. Please contact your administrator." : "Galat saat mengirim email. Silakan hubungi administrator Anda.",
+    "Successfully sent email to %1$s" : "Berhasil mengirim email ke %1$s",
     "Hello," : "Halo,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Kami ingin menginformasikan Anda bahwa %s telah mempublikasikan kalender »%s«.",
     "Open »%s«" : "Buka »%s«",
@@ -27,12 +27,12 @@ OC.L10N.register(
     "Dear %s, please confirm your booking" : "Kepada %s, mohon konfirmasi pemesanan Anda",
     "Confirm" : "Konfirmasi",
     "This confirmation link expires in %s hours." : "Tautan konfirmasi ini akan kedaluwarsa dalam %s jam.",
-    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas surel ini atau mengunjungi halaman profil mereka",
+    "If you wish to cancel the appointment after all, please contact your organizer by replying to this email or by visiting their profile page." : "Jika Anda ingin membatalkan janji temu, mohon hubungi penyelenggara Anda dengan membalas email ini atau mengunjungi halaman profil mereka",
     "Your appointment \"%s\" with %s has been accepted" : "Janji temu \"%s\" dengan %stelah diterima",
     "Dear %s, your booking has been accepted." : "Kepada %s, pemesanan Anda telah diterima.",
     "Appointment for:" : "Janji temu untuk:",
     "Date:" : "Tanggal:",
-    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan surel konfirmasi",
+    "You will receive a link with the confirmation email" : "Anda akan menerima tautan dengan email konfirmasi",
     "Where:" : "Tempat:",
     "Comment:" : "Komentar:",
     "You have a new appointment booking \"%s\" from %s" : "Anda memiliki pemesanan janji temu baru \"%s\" dari %s",
@@ -109,14 +109,14 @@ OC.L10N.register(
     "Deck" : "Longgok",
     "Hidden" : "Sembunyi",
     "An error occurred, unable to publish calendar." : "Terjadi galat, tidak dapat menerbitkan kalender.",
-    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim surel.",
+    "An error occurred, unable to send email." : "Terjadi galat, tidak dapat mengirim email.",
     "Embed code copied to clipboard." : "Kode tersemat disalin ke papan klip",
     "Embed code could not be copied to clipboard." : "Kode tersemat tidak dapat disalin ke papan klip.",
     "Unpublishing calendar failed" : "Gagal membatalkan penerbitan kalender",
     "Share link" : "Bagikan tautan",
     "Copy public link" : "Salin tautan publik",
-    "Send link to calendar via email" : "Kirim tautan kalender via surel",
-    "Sending email …" : "Mengirim surel …",
+    "Send link to calendar via email" : "Kirim tautan kalender via email",
+    "Sending email …" : "Mengirim email …",
     "Copy embedding code" : "Salin kode penyemat",
     "Copying code …" : "Menyalin kode …",
     "Copied code" : "Kode tersalin",
@@ -167,7 +167,7 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "Tampilkan pintasan papan kunci",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} menit"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} jam"],
-    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat surel Anda di pengaturan pribadi.",
+    "To configure appointments, add your email address in personal settings." : "Untuk mengonfigurasi janji temu, tambahkan alamat email Anda di pengaturan pribadi.",
     "Update" : "Perbarui",
     "Location" : "Lokasi",
     "Description" : "Deskrisi",
@@ -180,13 +180,13 @@ OC.L10N.register(
     "Friday" : "Jumat",
     "Saturday" : "Sabtu",
     "Sunday" : "Minggu",
-    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim surel dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam surel tersebut. Anda dapat menutup halaman ini sekarang.",
-    "Your email address" : "Alamat surel Anda",
+    "We sent you an email with details. Please confirm your appointment using the link in the email. You can close this page now." : "Kami telah mengirim email dengan detailnya. Mohon konfirmasikan janji temu Anda menggunakan tautan dalam email tersebut. Anda dapat menutup halaman ini sekarang.",
+    "Your email address" : "Alamat email Anda",
     "Could not book the appointment. Please try again later or contact the organizer." : "Tidak dapat memesan janji temu. Mohon coba lagi nanti atau hubungi penyelenggara.",
     "on" : "pada",
     "at" : "di",
     "Notification" : "Notifikasi",
-    "Email" : "Surel",
+    "Email" : "Email",
     "Audio notification" : "Notifikasi audio",
     "Other notification" : "Notifikasi lain",
     "Relative to event" : "Relatif terhadap acara",
@@ -231,7 +231,7 @@ OC.L10N.register(
     "No match found" : "Tidak ditemukan kecocokan",
     "Note that members of circles get invited but are not synced yet." : "Perhatikan bahwa anggota kelompok diundang tapi belum tersinkronisasi.",
     "(organizer)" : "(penyelenggara)",
-    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat surel Anda di pengaturan pribadi[linkclose].",
+    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Untuk mengirim undangan dan mengurus respons, [linkopen]tambahkan alamat email Anda di pengaturan pribadi[linkclose].",
     "Remove color" : "Hapus warna",
     "Event title" : "Judul acara",
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Tidak dapat mengubah pengaturan sehari penuh untuk acara yang merupakan bagian dari set pengulangan.",
