@@ -58,7 +58,7 @@ OC.L10N.register(
     "Appointment link was copied to clipboard" : "Plānotās tikšanās saite tika ievietota starpliktuvē.",
     "Appointment link could not be copied to clipboard" : "Plānotās tikšanās saiti nevarēja ievietot starpliktuvē.",
     "Preview" : "Priekšskatīt",
-    "Copy link" : "Kopēt saiti",
+    "Copy link" : "Ievietot saiti starpliktuvē",
     "Edit" : "Labot",
     "Delete" : "Izdzēst",
     "Create new" : "Izveidot jaunu",
@@ -85,10 +85,10 @@ OC.L10N.register(
     "Add custom public calendar" : "Pievienot pielāgotu publisko kalendāru",
     "Calendar link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
     "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevarēja ievietot starpliktuvē.",
-    "Copy subscription link" : "Kopēt publisko saiti",
-    "Copying link …" : "Saite tiek kopēta ...",
+    "Copy subscription link" : "Ievietot abonēšanas saiti starpliktuvē",
+    "Copying link …" : "Saite tiek ievietota starpliktuvē ...",
     "Copied link" : "Kopēta saite",
-    "Could not copy link" : "Neizdevās kopēt saiti",
+    "Could not copy link" : "Neizdevās ievietot saiti starpliktuvē",
     "Export" : "Izgūt",
     "Untitled item" : "Nenosaukts vienums",
     "Unknown calendar" : "Nezināms kalendārs",
@@ -108,14 +108,14 @@ OC.L10N.register(
     "Hidden" : "Paslēpts",
     "Internal link" : "Iekšējā saite",
     "A private link that can be used with external clients" : "Privāta saite, kas var tikt izmantota ar ārējiem klientiem.",
-    "Copy internal link" : "Kopēt iekšējo saiti",
+    "Copy internal link" : "Ievietot iekšējo saiti starpliktuvē",
     "An error occurred, unable to publish calendar." : "Atgadījās kļūda, neizdevās publiskot kalendāru.",
     "An error occurred, unable to send email." : "Atgadījās kļūda, nevarēja nosūtīt e-pasta ziņojumu.",
     "Embed code copied to clipboard." : "Iegulšanas kods ievietots starpliktuvē.",
     "Embed code could not be copied to clipboard." : "Iegulšanas kodu nevarēja ievietot starpliktuvē.",
     "Unpublishing calendar failed" : "Neizdevās atcelt kalendāra publicēšanu",
     "Share link" : "Koplietot saiti",
-    "Copy public link" : "Kopējiet publisko saiti",
+    "Copy public link" : "Ievietot publisko saiti starpliktuvē",
     "Send link to calendar via email" : "Nosūtīt saiti kalendāra saiti e-pastā",
     "Enter one address" : "Ievadiet vienu adresi",
     "Sending email …" : "Sūta e-pastu ...",
@@ -231,7 +231,6 @@ OC.L10N.register(
     "Add Talk conversation" : "Pievienot Talk sarunu",
     "Select conversation" : "Atlasīt sarunu",
     "at" : "plkst.",
-    "Reminder" : "Atgādinājums",
     "before at" : "pirms ",
     "Notification" : "Paziņojums",
     "Email" : "E-pasts",
@@ -242,7 +241,6 @@ OC.L10N.register(
     "Edit time" : "Labot laiku",
     "Save time" : "Saglabāt laiku",
     "Remove reminder" : "Noņemt atgādinājumu",
-    "+ Add reminder" : "Pievienot atgādinājumu",
     "Add reminder" : "Pievienot atgādinājumu",
     "seconds" : "sekundes",
     "minutes" : "minūtes",
@@ -272,14 +270,14 @@ OC.L10N.register(
     "Checking availability" : "Pārbauda pieejamību",
     "Has not responded to {organizerName}'s invitation yet" : "Vēl nav atbildējis uz {organizerName} uzaicinājumu",
     "{attendee} ({role})" : "{attendee} ({role})",
+    "Availability of attendees, resources and rooms" : "Dalībnieku, resursu un telpu pieejamība",
+    "Out of office" : "Ārpus biroja",
+    "Done" : "Pabeigts",
+    "Room name" : "Sapulču telpas nosaukums",
     "Free" : "Brīvs",
     "Busy (tentative)" : "Aizņemts (nenoteikts)",
     "Busy" : "Aizņemts",
-    "Out of office" : "Ārpus biroja",
     "Unknown" : "Nezināms",
-    "Availability of attendees, resources and rooms" : "Dalībnieku, resursu un telpu pieejamība",
-    "Done" : "Pabeigts",
-    "Room name" : "Sapulču telpas nosaukums",
     "Find a time" : "Atrast laiku",
     "The invitation has been accepted successfully." : "Uzaicinājums ir veiksmīgi apstiprināts.",
     "Failed to accept the invitation." : "Neizdevās apstiprināt uzaicinājumu.",
@@ -293,7 +291,7 @@ OC.L10N.register(
     "No attendees yet" : "Vēl nav dalībnieku",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
     "Error creating Talk room" : "Notika kļūda, veidojot tērzēšanas istabu",
-    "Attendees" : "Apmeklētāji",
+    "Attendees" : "Dalībnieki",
     "Remove group" : "Noņemt grupu",
     "Remove attendee" : "Noņemt dalībnieku",
     "Request reply" : "Pieprasīt atbildi",
@@ -306,7 +304,6 @@ OC.L10N.register(
     "Cannot modify all-day setting for events that are part of a recurrence-set." : "Nevar modificēt visas dienas iestatījumu notikumiem, kas ir daļa no atkārtojumu kopas.",
     "From" : "No",
     "To" : "Līdz",
-    "All day" : "Visas dienas",
     "Repeat" : "Atkārtot",
     "never" : "nekad",
     "on date" : "datumā",
@@ -323,7 +320,7 @@ OC.L10N.register(
     "Does not repeat" : "Neatkārtojas",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Atkārtošanās definīcija šim notikumam Nextcloud nav pilnībā atbalstīta. Ja tiek labotas atkārtošanās iespējas, noteikti atkārtojošies notikumi var tikt zaudēti.",
     "No rooms or resources yet" : "Vēl nav telpu vai resursu.",
-    "Suggestions" : "Ieteikumi",
+    "Resources" : "Resursi",
     "Add resource" : "Pievienot resursu",
     "Has a projector" : "Ir projektors",
     "Has a whiteboard" : "Ir tāfele",
@@ -369,14 +366,14 @@ OC.L10N.register(
     "Book another appointment:" : "Rezervēt vēl vienu plānotu tikšanos",
     "Book an appointment with {name}" : "Rezervējiet plānotu tikšanos ar {name}",
     "Personal" : "Personīgs",
+    "Edit event" : "Rediģēt notikumu",
     "Event does not exist" : "Notikums nepastāv",
     "Duplicate" : "Pavairot",
     "Delete this occurrence" : "Izdzēst šo notikumu",
-    "Details" : "Informācija",
+    "All day" : "Visas dienas",
     "Managing shared access" : "Koplietotās piekļuves pārvaldība",
     "Deny access" : "Liegt piekļuvi",
     "Invite" : "Uzaicināt",
-    "Resources" : "Resursi",
     "_User requires access to your file_::_Users require access to your file_" : ["Lietotāji pieprasa piekļuvi Tavai datnei","Lietotājs pieprasa piekļuvi Tavai datnei","Lietotāji pieprasa piekļuvi Tavai datnei"],
     "Untitled event" : "Nenosaukts notikums",
     "Close" : "Aizvērt",
@@ -459,6 +456,10 @@ OC.L10N.register(
     "Imported {filename}" : "Importēts {filename}",
     "This is an event reminder." : "Šis ir notikuma atgādinājums.",
     "Appointment not found" : "Tikšanās nav atrasta",
-    "User not found" : "Lietotājs nav atrasts"
+    "User not found" : "Lietotājs nav atrasts",
+    "Reminder" : "Atgādinājums",
+    "+ Add reminder" : "Pievienot atgādinājumu",
+    "Suggestions" : "Ieteikumi",
+    "Details" : "Informācija"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
